@@ -132,20 +132,13 @@ See also the `profile' slot in the `browser' class.")
               :padding "0.2em"
               :margin "0.2em"
               :min-height "2rem")
-            `(.button.accent
-              :background-color ,theme:accent
-              :color ,theme:on-accent
-              :border-color ,theme:accent)
             `(select.button
               :appearance auto
               :background-color ,theme:primary !important
               ;; WebKit does not allow to style <select> tags and always leaves
               ;; us with white buttons in place of those. So we need to use an
               ;; invariably dark color for the text on it
-              :color ,(if (theme:dark-p theme:theme)
-                          theme:background
-                          theme:on-background)
-              !important
+              :color ,(theme:contrasting-text-color theme:theme "white") !important
               :min-height "2rem")
             `((:and .button :hover)
               :cursor "pointer"
@@ -159,8 +152,30 @@ See also the `profile' slot in the `browser' class.")
               :color ,theme:primary)
             `(".link:hover"
               :opacity 0.8)
-            `(.accent
-              :color ,theme:accent)
+            `(.action
+              :color ,theme:action)
+	    `(.button.action
+              :background-color ,theme:action
+              :color ,theme:on-action
+              :border-color ,theme:action+)
+            `(.warning
+              :color ,theme:warning)
+	    `(.button.warning
+	      :background-color ,theme:warning
+	      :color ,theme:on-warning
+	      :border-color ,theme:warning+)
+            `(.success
+              :color ,theme:success)
+	    `(.button.success
+               :background-color ,theme:success
+               :color ,theme:on-success
+               :border-color ,theme:success+)
+            `(.highlight
+              :color ,theme:highlight)
+	    `(.button.highlight
+	      :background-color ,theme:highlight
+	      :color ,theme:on-highlight
+	      :border-color ,theme:highlight+)
             `(.plain
               :color ,theme:on-background
               :background-color ,theme:background)
@@ -181,14 +196,19 @@ See also the `profile' slot in the `browser' class.")
             `(pre
               :border-radius "3px"
               :overflow "auto"
-              :color ,theme:on-background
-              :background-color ,theme:background
-              :border "2px" solid ,theme:primary
               :padding "5px")
             `("table"
               :border-radius "3px"
               :border-spacing "0"
               :width "100%")
+            `("pre, p code"
+              :color ,theme:on-codeblock
+              :background-color ,theme:codeblock)
+            ;; FIXME: CSS4 has a :has() selector that would be perfect here:
+            ;; a:has(code) { color: theme:on-codeblock;} Unfortunately, LASS
+            ;; doesn't (yet?) support it. Thus the hack:
+            `("a code"
+              :text-decoration underline)
             `("table, th, td"
               :border-color ,theme:secondary
               :border-width "1px"
@@ -205,8 +225,8 @@ See also the `profile' slot in the `browser' class.")
               :font-weight "bold"
               :margin-top "2em")
             `("::selection"
-              :color ,theme:on-accent
-              :background-color ,theme:accent)))
+              :color ,theme:on-action
+              :background-color ,theme:action)))
    (buffer-delete-hook          ; TODO: Should we move this to `context-buffer'?
     (make-instance 'hook-buffer)
     :type hook-buffer
@@ -783,9 +803,30 @@ store them somewhere and `ffi-buffer-delete' them once done."))
               :border-radius "2px"
               :padding "6px"
               :margin "2px")
-            `(.button.accent
-              :background-color ,theme:accent
-              :color ,theme:on-accent)
+	    `(.action
+              :color ,theme:action)
+	    `(.button.action
+              :background-color ,theme:action
+              :color ,theme:on-action
+              :border-color ,theme:action+)
+            `(.warning
+              :color ,theme:warning)
+	    `(.button.warning
+	      :background-color ,theme:warning
+	      :color ,theme:on-warning
+	      :border-color ,theme:warning+)
+            `(.success
+              :color ,theme:success)
+	    `(.button.success
+               :background-color ,theme:success
+               :color ,theme:on-success
+               :border-color ,theme:success+)
+            `(.highlight
+              :color ,theme:highlight)
+	    `(.button.highlight
+	      :background-color ,theme:highlight
+	      :color ,theme:on-highlight
+	      :border-color ,theme:highlight+)
             `((:and .button :hover)
               :cursor "pointer"
               :opacity 0.8)
@@ -842,8 +883,8 @@ Also see `panel-page'."))
               :border-width "2px"
               :border-style "solid"
               :border-color "transparent"
-              :border-top-color ,theme:accent
-              :border-left-color ,theme:accent
+              :border-top-color ,theme:action
+              :border-left-color ,theme:action
               :border-radius "50%"
               :display "inline-block"
               :width "7px"
@@ -949,9 +990,9 @@ Also see `panel-page'."))
               :padding 0
               :font "inherit"
               :outline "inherit")
-            `(.button.accent
-              :background-color ,theme:accent
-              :color ,theme:on-accent)
+            `(.button.action
+              :background-color ,theme:action
+              :color ,theme:on-action)
             `((:and .button :hover)
               :cursor "pointer"
               :opacity 0.6)
@@ -1411,24 +1452,9 @@ second latest buffer first."
       (set-current-buffer buffer)
       (prompt
        :prompt "Switch to buffer"
-       :sources (list
-                 (make-instance 'buffer-source
-                                :constructor (buffer-initial-suggestions
-                                              :current-is-last-p current-is-last-p))
-                 (make-instance
-                  'new-url-or-search-source
-                  :name "Create new buffer"
-                  :actions-on-return (list (lambda-command new-buffer-load* (suggestion-values)
-                                             "Load URL(s) in new buffer(s)"
-                                             (mapc (lambda (suggestion) (make-buffer :url (url suggestion)))
-                                                   (rest suggestion-values))
-                                             (make-buffer-focus :url (url (first suggestion-values))))
-                                           (lambda-command new-nosave-buffer-load* (suggestion-values)
-                                             "Load URL(s) in new nosave buffer(s)"
-                                             (mapc (lambda (suggestion) (make-nosave-buffer :url (url suggestion)))
-                                                   (rest suggestion-values))
-                                             (make-buffer-focus :url (url (first suggestion-values))
-                                                                :nosave-buffer-p t))))))))
+       :sources (make-instance 'buffer-source
+                               :constructor (buffer-initial-suggestions
+                                             :current-is-last-p current-is-last-p)))))
 
 (define-command switch-buffer-domain (&key domain (buffer (current-buffer)))
   "Switch the active buffer in the current window from the current domain."
@@ -1816,18 +1842,11 @@ specified for their contents."
   (if explicit-url-p
       (make-buffer-focus :url (url url))
       (let ((history (set-url-history *browser*))
-            (actions-on-return
-              (list (lambda-command new-buffer-load (suggestion-values)
-                      "Load URL(s) in new buffer(s)"
-                      (mapc (lambda (suggestion) (make-buffer :url (url suggestion)))
-                            (rest suggestion-values))
-                      (make-buffer-focus :url (url (first suggestion-values))))
-                    (lambda-command new-nosave-buffer-load (suggestion-values)
-                      "Load URL(s) in new nosave buffer(s)"
-                      (mapc (lambda (suggestion) (make-nosave-buffer :url (url suggestion)))
-                            (rest suggestion-values))
-                      (make-buffer-focus :url (url (first suggestion-values))
-                                         :nosave-buffer-p t)))))
+            (actions-on-return (lambda-command new-buffer-load (suggestion-values)
+                                 "Load URL(s) in new buffer(s)"
+                                 (mapc (lambda (suggestion) (make-buffer :url (url suggestion)))
+                                       (rest suggestion-values))
+                                 (make-buffer-focus :url (url (first suggestion-values))))))
         (pushnew-url-history history (url (current-buffer)))
         (prompt
          :prompt "Open URL in new buffer"
