@@ -875,3 +875,19 @@ Nyxt version exists.  It is only raised when the major version differs.")
      (:li "Buffers of type " (:nxref :class-name 'nyxt/mode/editor:editor-buffer) " have  "
           (:nxref :class-name 'nyxt/mode/editor:plaintext-editor-mode)
           "enabled by default."))))
+
+(define-version "3.9.0"
+  (:nsection :title "Features"
+    (:ul
+     (:li "Complete refactor of the "
+          (:a :href (nyxt-url 'common-settings) "Common Settings Menu") ".")
+     (:li "Refactor the " (:nxref :package :theme)
+	  " API to allow for more nuanced themes and richer interfaces.")))
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix the functionality of the download cancellation button.")
+     (:li "Fix duplicated suggestions when issuing command "
+          (:nxref :command 'describe-slot) ".")
+     (:li "Fix accepted values of "
+          (:nxref :class-name 'browser :slot 'external-editor-program)
+          "."))))
