@@ -9,7 +9,6 @@ The APIs that it includes/uses internally are:
 - Page scrolling: `call-non-input-command-or-forward'.
 - Copy-pasting: `ffi-buffer-copy', `ffi-buffer-paste', `ffi-buffer-cut',
   `ffi-buffer-select-all', `ffi-buffer-undo', `ffi-buffer-redo'.
-- Nyxt renderer signals: `on-signal-load-committed', `on-signal-load-finished'
 - Heading management: `heading' class, `get-headings', `current-heading',
   `scroll-page-to-heading', and `scroll-page-to-n-headings'.
 - `get-url-source' function.
@@ -210,7 +209,9 @@ Important pieces of functionality are:
    (prompter:actions-on-return (lambda-command paste* (ring-items)
                                  (ffi-buffer-paste (current-buffer) (first ring-items)))))
   (:export-class-name-p t)
-  (:metaclass user-class))
+  (:metaclass user-class)
+  (:documentation "Source for previous clipboard contents.
+Only includes the strings that were pasted/copied inside Nyxt."))
 
 (define-command paste-from-clipboard-ring ()
   "Show `*browser*' clipboard ring and paste selected entry."
@@ -261,10 +262,6 @@ Important pieces of functionality are:
           do (nyxt/dom:focus-select-element input)
           and do (return input)))
 
-(defmethod nyxt:on-signal-load-committed ((mode document-mode) url)
-  (declare (ignore mode url))
-  nil)
-
 (defmethod nyxt:on-signal-load-finished ((mode document-mode) url)
   (reset-page-zoom :buffer (buffer mode)
                    :ratio (current-zoom-ratio (buffer mode)))
@@ -290,6 +287,9 @@ Warning: URL is a string."
 
 (export-always 'get-url-source)
 (defun get-url-source (url)
+  "Get HTML source for URL page, as a string.
+If the page is open in one of the buffers, just get the source from there.
+Otherwise, create a dummy buffer with URL to get its source."
   (let ((buffer (or (find (url url) (buffer-list) :test #'quri:uri= :key #'url)
                     (make-background-buffer :url (url url)))))
     (unwind-protect
@@ -419,7 +419,7 @@ The inner-text must not be modified, so that we can jump to the anchor of the sa
   (ps-labels :buffer buffer
     ((heading-scroll-position
       :buffer buffer (element)
-      (ps:chain (nyxt/ps:qs-nyxt-id document (ps:lisp (nyxt/dom:get-nyxt-id element)))
+      (ps:chain (nyxt/ps:rqs-nyxt-id document (ps:lisp (nyxt/dom:get-nyxt-id element)))
                 (get-bounding-client-rect) y)))
     (map 'list
          (lambda (e)
@@ -450,9 +450,10 @@ The inner-text must not be modified, so that we can jump to the anchor of the sa
   "Scroll to the N adjacent heading of the BUFFER."
   (sera:and-let* ((headings (get-headings :buffer buffer))
                   (new-position (+ n
-                                   (position (element (current-heading buffer))
+                                   (position (nyxt/dom:body (element (current-heading buffer)))
                                              headings
-                                             :key #'element)))
+                                             :key (compose #'nyxt/dom:body #'element)
+                                             :test #'equal)))
                   (_ (<= 0 new-position (1- (length headings)))))
     (scroll-page-to-heading (elt headings new-position))))
 
